=====================
Troubleshooting
=====================

.. currentmodule:: larch.model.troubleshooting


.. autosummary::
    :toctree: generated/

    doctor
    chosen_but_not_available
    chosen_but_zero_quantity
    nothing_chosen_but_nonzero_weight
    nan_data_co
    nan_weight
    low_variance_data_co
    overspecification
